@@ -225,8 +225,9 @@ void MainWindow::orientationChanged()
 
 
 void MainWindow::updateProgress(){
+    static int progress = 0;
     progress++;
-    qDebug() << progress;
+    //qDebug() << progress;
     if (!resultWindow){
         progressbar->setValue((progress*5) % 100);
     }
@@ -234,8 +235,10 @@ void MainWindow::updateProgress(){
         progressbarResult->setValue((progress*5) % 100);
     }
 
-    if(progress > 250){ // 20ms * 50 * 5 = 5 sec
+    if(progress > 1500){ // 20ms * 50 * 30 = 30 sec
         backendParser->httpRequestTimeout();
+        timeout = true;
+        progress = 0;
     }
 }
 
@@ -422,10 +425,10 @@ void MainWindow::resultItemClicked()
         detailsLoading = true;
 
 
-        progress=0;
+        timeout=false;
         progressbarResult->show();
         timer->start(20); //start timer with 20ms interval
-
+qDebug() << data->item.detailsUrl;
         lastSearchDetails = backendParser->getJourneyDetailsData(data->item.detailsUrl);
 
         progressbarResult->hide();
@@ -450,7 +453,7 @@ void MainWindow::showDetailsWindow()
     }
 
 
-    if(progress>250){
+    if(timeout){
         QMaemo5InformationBox::information(this, "<br>No response from server.<br>", QMaemo5InformationBox::DefaultTimeout);
         return;
     }
@@ -591,7 +594,7 @@ void MainWindow::showResultWindow()
         resultWindow->hide();
     }
 
-    if(progress>250){
+    if(timeout){
         QMaemo5InformationBox::information(this, "<br>No response from server.<br>", QMaemo5InformationBox::DefaultTimeout);
         searchButton->setEnabled(true);
         return;
@@ -848,7 +851,7 @@ void MainWindow::searchButtonClicked(bool checked)
 
             searchButton->setEnabled(false);
 
-            progress=0;
+            timeout=false;
             progressbar->show();
             timer->start(20); //start timer with 20ms interval
 
