@@ -20,6 +20,16 @@
 
 #include "parser_abstract.h"
 
+
+void parserAbstract::httpDataReadProgress(int done, int total)
+{
+    qDebug() << "httpDataReadProgress:" << done << "/" << total;
+    progress = done;
+    progressTotal = total;
+}
+
+
+
 void parserAbstract::httpRequestFinished(int requestId, bool error)
 {
     Q_UNUSED(error);
@@ -27,6 +37,45 @@ void parserAbstract::httpRequestFinished(int requestId, bool error)
     loop.exit();
 }
 
+
+void parserAbstract::httpRequestTimeout()
+{
+    loop.exit();
+}
+
+
+
+
+//void parserAbstract::NetworkManagerInit(void)
+//{
+//    qDebug() << "NetworkManager init";
+
+
+//}
+
+
+
+
+
+//void parserAbstract::replyFinished(QNetworkReply*)
+//{
+//    qDebug() << "NetworkManager reply finished";
+//    loop.exit();
+//}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 bool parserAbstract::supportsGps()
 {
     return false;
