@@ -49,6 +49,9 @@ parserHafasXml::parserHafasXml(QObject *parent)
      //baseUrl = "http://www.rejseplanen.dk/bin/query.exe";//?? No Gps, returns only one result //no xmlhandle, detaildate already present!
      //baseUrl = "http://airs1.septa.org/bin/query.exe";// not working at all
 
+     hafasHeader.accessid = "";
+     hafasHeader.prod = "String";
+     hafasHeader.ver = "1.1";
 }
 
 bool parserHafasXml::supportsGps()
@@ -116,7 +119,8 @@ ResultInfo parserHafasXml::getJourneyData(QString queryUrl)
         append = false;
     }
 
-    QByteArray apostData = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?><ReqC ver=\"1.1\" prod=\"String\" lang=\"EN\">";
+    QByteArray apostData = "";
+    apostData.append("<?xml version=\"1.0\" encoding=\"UTF-8\" ?><ReqC  accessId=\"" + hafasHeader.accessid + "\" ver=\"" + hafasHeader.ver + "\" prod=\"" + hafasHeader.prod + "\" lang=\"EN\">");
     apostData.append("<ConScrReq scrDir=\"");
     apostData.append(direction);
     apostData.append("\" nrCons=\"5\">");
@@ -297,10 +301,21 @@ ResultInfo parserHafasXml::parseJourneyData(QByteArray data, bool append)
         item.fromTime   = cleanHafasDate(depTimeResult.join("").trimmed());
         item.toTime     = cleanHafasDate(arrTimeResult.join("").trimmed());
         item.detailsUrl = xmlHandleResult.join("").trimmed();
+
+        bool hasInline = false;
+
+        if (item.detailsUrl.count() > 0 && item.detailsUrl.indexOf("extxml.exe")) {
+            hasInline = true;
+        }
+
         if (item.detailsUrl.count() > 0) {
             item.detailsUrl.remove(0, item.detailsUrl.indexOf("query.exe") + 9);
             item.detailsUrl.prepend(baseUrl);
         } else {
+            hasInline = true;
+        }
+
+        if (hasInline) {
             item.detailsInfo = parseJourneyDataDetails(data, resultIds[i], date);
         }
 
@@ -369,7 +384,8 @@ ResultInfo parserHafasXml::getJourneyData(QString destinationStation, QString ar
 
     //First Request, to get external ids
 
-    QByteArray apostData = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?><ReqC ver=\"1.1\" prod=\"String\" lang=\"EN\">";
+    QByteArray apostData = "";
+    apostData.append("<?xml version=\"1.0\" encoding=\"UTF-8\" ?><ReqC  accessId=\"" + hafasHeader.accessid + "\" ver=\"" + hafasHeader.ver + "\" prod=\"" + hafasHeader.prod + "\" lang=\"EN\">");
     apostData.append("<LocValReq id=\"from\" maxNr=\"1\"><ReqLoc match= \"");
     apostData.append(destinationStation);
     apostData.append("\" type=\"ST\"/></LocValReq>");
@@ -416,7 +432,8 @@ ResultInfo parserHafasXml::getJourneyData(QString destinationStation, QString ar
 
     //Second request with the search itself
 
-    apostData = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?><ReqC ver=\"1.1\" prod=\"String\" lang=\"EN\">";
+    apostData = "";
+    apostData.append("<?xml version=\"1.0\" encoding=\"UTF-8\" ?><ReqC  accessId=\"" + hafasHeader.accessid + "\" ver=\"" + hafasHeader.ver + "\" prod=\"" + hafasHeader.prod + "\" lang=\"EN\">");
     apostData.append("<ConReq>");
     apostData.append("<Start min=\"0\">");
     apostData.append("<Station externalId=\"");
@@ -776,7 +793,8 @@ QStringList parserHafasXml::getStationsByGPS(qreal latitude, qreal longitude)
 QStringList parserHafasXml::getStationsByName(QString stationName)
 {
     stationName.replace("\"", "");
-    QByteArray postData = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?><ReqC ver=\"1.1\" prod=\"String\" lang=\"EN\"><MLcReq><MLc n=\"";
+    QByteArray postData = "";
+    postData.append("<?xml version=\"1.0\" encoding=\"UTF-8\" ?><ReqC  accessId=\"" + hafasHeader.accessid + "\" ver=\"" + hafasHeader.ver + "\" prod=\"" + hafasHeader.prod + "\" lang=\"EN\"><MLcReq><MLc n=\"");
     postData.append(stationName);
     postData.append("\" t=\"ST\" /></MLcReq></ReqC>");
 
