@@ -28,6 +28,13 @@
 
 #include "parser_abstract.h"
 
+struct ParserHafasXmlHeader
+{
+    QString prod;
+    QString ver;
+    QString accessid;
+};
+
 class parserHafasXml : public parserAbstract
 {
     Q_OBJECT
@@ -45,6 +52,7 @@ public:
 protected:
     QHttp *http;
     QString baseUrl;
+    ParserHafasXmlHeader hafasHeader;
     QNetworkAccessManager *NetworkManager;
     QNetworkRequest request;
 
