@@ -202,18 +202,67 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
 
     QString xhtml = filebuffer->buffer();
 
+    QDateTime routeStart;
+    QDateTime routeEnd;
+
+    {
+        QRegExp regexp = QRegExp("<div class=\"querysummary2 (.*)\".*>.*([0-3][0-9]\\.[0-1][0-9]\\.[0-9][0-9]).*([0-9][0-9]:[0-9][0-9]).*-.*([0-3][0-9]\\.[0-1][0-9]\\.[0-9][0-9]).*([0-9][0-9]:[0-9][0-9]).*</div>");
+        regexp.setMinimal(true);
+        regexp.indexIn(xhtml);
+        if (regexp.cap(0)!="")
+        {
+            qDebug() << "******" << regexp.cap(0);
+            QDate date=QDate::fromString(regexp.cap(2).trimmed(),"dd.MM.yy");
+            date = date.addYears(100);
+            QTime time=QTime::fromString(regexp.cap(3).trimmed(),"hh:mm");
+            routeStart=QDateTime(date,time);
+            date=QDate::fromString(regexp.cap(4).trimmed(),"dd.MM.yy");
+            date = date.addYears(100);
+            time=QTime::fromString(regexp.cap(5).trimmed(),"hh:mm");
+            routeEnd=QDateTime(date,time);
+        }
+        else {
+            regexp.setPattern("<div class=\"querysummary2 (.*)\".*>.*([0-3][0-9]\\.[0-1][0-9]\\.[0-9][0-9]).*([0-9][0-9]:[0-9][0-9]).*\\-.*([0-9][0-9]:[0-9][0-9]).*</div>");
+            regexp.indexIn(xhtml);
+            if (regexp.cap(0)!="")
+            {
+                qDebug() << "******" << regexp.cap(0);
+                QDate date=QDate::fromString(regexp.cap(2).trimmed(),"dd.MM.yy");
+                date = date.addYears(100);
+                QTime time=QTime::fromString(regexp.cap(3).trimmed(),"hh:mm");
+                routeStart=QDateTime(date,time);
+                time=QTime::fromString(regexp.cap(4).trimmed(),"hh:mm");
+                routeEnd=QDateTime(date,time);
+            }
+            else qDebug() << "time and date not found";
+        }
+    }
+
     //We use Regex to get each element details page
-    QRegExp regexp = QRegExp("<div class=\"rline haupt\".*>(.*)</div>");
+    QRegExp regexp = QRegExp("<div class=\"rline haupt (.*)\".*>(.*)</div>");
     regexp.setMinimal(true);
 
     int idx = 0;
     int num = 0;
+    DetailResultItem fromStationItem;
+    DetailResultItem toStationItem;
+    QTime lastTime=routeStart.time();
+    QDate currentDate=routeStart.date();
     while (idx >= 0)
     {
         idx = regexp.indexIn(xhtml, idx);
+        //qDebug() << "DB Mobile:" << idx;
         if (idx >= 0)
         {
+            QString divType=regexp.cap(1);
+            enum { ROUTE_NONE, ROUTE_START, ROUTE_CHANGE, ROUTE_END, ROUTE_MOT } divMode = ROUTE_NONE;
+            if (divType.contains("routeStart")) divMode=ROUTE_START;
+            if (divType.contains("routeChange")) divMode=ROUTE_CHANGE;
+            if (divType.contains("routeEnd")) divMode=ROUTE_END;
+            if (divType.contains("mot")) divMode=ROUTE_MOT;
+
             num++;
+            DetailResultItem stationInfo;
             QBuffer readBuffer;
             QString element = "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n<body>\n" + regexp.cap(0) + "\n</body>\n</html>\n";
 
@@ -244,8 +293,14 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
                 qDebug() << "parserMobileBahnDe::getJourneyDetailsData - Query 2 Failed";
             }
 
-            query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/child::text()/string()");
-
+            if (divMode==ROUTE_MOT)
+            {
+                query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/a/child::text()/string()");
+            }
+            else
+            {
+                query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/child::text()/string()");
+            }
             QStringList txtResults;
             if (!query.evaluateTo(&txtResults))
             {
@@ -261,65 +316,177 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
             qDebug() <<txtResults;
             */
 
-            if (stationResults.count() == 2)
+
+
+            if (stationResults.count() > 0)
+            {
+                qDebug() << "Station:" << divMode << "(" << divType << ") " << stationResults[0].trimmed();
+                if (divMode==ROUTE_START)
+                {
+                    fromStationItem.fromStation = stationResults[0].trimmed();
+                }
+                if (divMode==ROUTE_END || divMode == ROUTE_CHANGE)
+                {
+                    fromStationItem.toStation   = stationResults[0].trimmed();
+                    toStationItem.fromStation = fromStationItem.toStation;
+                }
+            }
+            if (divMode==ROUTE_MOT)
             {
-                DetailResultItem item;
-                item.fromStation = stationResults[0].trimmed();
-                item.toStation   = stationResults[1].trimmed();
                 if (trainnrResults.count() > 0)
                 {
-                    item.train = trainnrResults[0].trimmed();
+                    fromStationItem.train = trainnrResults[0].trimmed();
+                }
+                else {
+                    fromStationItem.train = txtResults.join(" ").trimmed();
+                    qDebug() << "no train found" << fromStationItem.train;
                 }
 
+            }
+            if (stationResults.count() > 0)
+            {
                 QString tmp = txtResults.join(" ");
                 tmp.replace("  ", " ");
                 tmp.replace("\n", " ");
 
                 //Check and Parse departure and arrival Times
-                QRegExp tmpRegexp = QRegExp("(dep) (.+) on (.*) (arr) (.+) on (.*) ");
-                tmpRegexp.setMinimal(true);
-                tmpRegexp.indexIn(tmp);
-
-                if (tmpRegexp.cap(0) != "")
-                {
-                    if (tmpRegexp.cap(1) == "dep")
+                bool depFound=false;
+                bool arrFound=false;
+                bool minFound=false;
+                QRegExp tmpRegexp = QRegExp("(arr|dep) ([0-9:]+) +[PG]l\\. ([0-9]+ ?[A-H]?\\-?[A-H]?)");
+                tmpRegexp.setMinimal(false);
+                int depArrIndex=0;
+                while (depArrIndex>=0) {
+                    depArrIndex=tmpRegexp.indexIn(tmp,depArrIndex);
+                    if (depArrIndex>=0)
                     {
-                        item.fromInfo = tmpRegexp.cap(2).trimmed() + " on " + tmpRegexp.cap(3).trimmed();
+                        QString info = tmpRegexp.cap(2).trimmed() + " on " + tr("Platform ") + tmpRegexp.cap(3).trimmed();
 
                         QRegExp tmpRegexp2 = QRegExp("(\\d\\d:\\d\\d)");
                         tmpRegexp2.setMinimal(true);
                         tmpRegexp2.indexIn(tmpRegexp.cap(2).trimmed());
 
-                        QDate fromDate = QDate::fromString(tmpRegexp.cap(3).trimmed(), "dd.MM.yy");
-                        QTime fromTime = QTime::fromString(tmpRegexp2.cap(1).trimmed(), "hh:mm");
+                        QTime time = QTime::fromString(tmpRegexp2.cap(1).trimmed(), "hh:mm");
+                        if (time<lastTime) {
+                            currentDate=currentDate.addDays(1);
+                            lastTime=time;
+                        }
 
-                        fromDate = fromDate.addYears(100); //default is 1900 so we add 100years
-                        item.fromTime.setDate(fromDate);
-                        item.fromTime.setTime(fromTime);
+                        QDateTime dateTime;
+                        dateTime.setDate(currentDate);
+                        dateTime.setTime(time);
+                        if (tmpRegexp.cap(1)=="arr") {
+                            fromStationItem.toInfo = info;
+                            fromStationItem.toTime = dateTime;
+                            arrFound=true;
+                        }
+                        else {
+                            if (divMode==ROUTE_START)
+                            {
+                                fromStationItem.fromInfo = info;
+                                fromStationItem.fromTime = dateTime;
+                            }
+                            else
+                            {
+                                toStationItem.fromInfo = info;
+                                toStationItem.fromTime = dateTime;
+                            }
+                            depFound=true;
+
+                        }
+                        ++depArrIndex;
                     }
-                    if (tmpRegexp.cap(4) == "arr")
-                    {
-                        item.toInfo = tmpRegexp.cap(5).trimmed() + " on " + tmpRegexp.cap(6).trimmed();
 
-                        QRegExp tmpRegexp2 = QRegExp("(\\d\\d:\\d\\d)");
-                        tmpRegexp2.setMinimal(true);
-                        tmpRegexp2.indexIn(tmpRegexp.cap(5).trimmed());
-
-                        QDate toDate = QDate::fromString(tmpRegexp.cap(6).trimmed(), "dd.MM.yy");
-                        QTime toTime = QTime::fromString(tmpRegexp2.cap(1).trimmed(), "hh:mm");
-
-                        toDate = toDate.addYears(100); //default is 1900 so we add 100years
-                        item.toTime.setDate(toDate);
-                        item.toTime.setTime(toTime);
-                    }
-                } else
-                {
-                    tmp = tmp.trimmed();
-                    item.info.append(tmp);
                 }
 
-                result.items.append(item);
-            } else
+                if (!depFound || !arrFound) {
+                    tmpRegexp.setPattern("(arr|dep) ([0-9:]+)");
+                    if (depFound)
+                        tmpRegexp.setPattern("(arr) ([0-9:]+)");
+                    if (arrFound)
+                        tmpRegexp.setPattern("(dep) ([0-9:]+)");
+
+                    tmpRegexp.setMinimal(false);
+                    int depArrIndex=0;
+                    while (depArrIndex>=0) {
+                        depArrIndex=tmpRegexp.indexIn(tmp,depArrIndex);
+                        if (depArrIndex>=0)
+                        {
+                            QString info = tmpRegexp.cap(2).trimmed();
+
+                            QRegExp tmpRegexp2 = QRegExp("(\\d\\d:\\d\\d)");
+                            tmpRegexp2.setMinimal(true);
+                            tmpRegexp2.indexIn(tmpRegexp.cap(2).trimmed());
+
+                            QTime time = QTime::fromString(tmpRegexp2.cap(1).trimmed(), "hh:mm");
+                            if (time<lastTime) {
+                                currentDate=currentDate.addDays(1);
+                                lastTime=time;
+                            }
+
+                            QDateTime dateTime;
+                            dateTime.setDate(currentDate);
+                            dateTime.setTime(time);
+                            if (tmpRegexp.cap(1)=="arr") {
+                                fromStationItem.toInfo = info;
+                                fromStationItem.toTime = dateTime;
+                                arrFound=true;
+                            }
+                            else {
+                                if (divMode==ROUTE_START)
+                                {
+                                    fromStationItem.fromInfo = info;
+                                    fromStationItem.fromTime = dateTime;
+                                }
+                                else
+                                {
+                                    toStationItem.fromInfo = info;
+                                    toStationItem.fromTime = dateTime;
+                                }
+                                depFound=true;
+
+                            }
+                            ++depArrIndex;
+                        }
+
+                    }
+
+                }
+
+                if (!depFound) {
+                    tmpRegexp.setPattern("([0-9:]+) (min\\.)");
+                    tmpRegexp.setMinimal(false);
+                    tmpRegexp.indexIn(tmp);
+                    if (tmpRegexp.cap(0) != "")
+                    {
+                        QString info = tmpRegexp.cap(1).trimmed() + " min.";
+
+                        if (divMode==ROUTE_START)
+                        {
+                            fromStationItem.fromInfo = info;
+                        }
+                        else
+                        {
+                            toStationItem.fromInfo = info;
+                        }
+                        minFound=true;
+                    }
+                }
+
+
+                if (!depFound && !arrFound && !minFound)
+                {
+                    tmp = tmp.trimmed();
+                    fromStationItem.info.append(tmp);
+                }
+
+                if (divMode!=ROUTE_START) {
+                    result.items.append(fromStationItem);
+                    fromStationItem = toStationItem;
+                    toStationItem = DetailResultItem();
+                }
+            }
+            else
             {
                 for (int i = 0; i < txtResults.count(); i++)
                 {
@@ -385,9 +552,14 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
         result.info += errormsgsResults.join("").trimmed();
     }
 
+    int secs=routeStart.secsTo(routeEnd);
+    int hours=secs/3600;
+    int minutes=(secs-hours*3600)/60;
+    result.duration=QString("(%1h, %2m)").arg(hours).arg(minutes);
     return result;
 }
 
+
 ResultInfo parserMobileBahnDe::getJourneyData(QString queryUrl)
 {
     QUrl url(queryUrl);
